@@ -22,12 +22,18 @@ class ApiSettings(ApiBase):
     def aws_cloud_accounts(self):
         return self.build_route("settings/cloudaccounts/aws")
 
+    # todo old function -> tomer delete this in phase 2
     def add_compute_service_aks(self):
         return self.build_route("settings/cloudaccounts/azure/computeservices/aks")
 
+    # todo old function -> tomer delete this in phase 2
     def add_compute_service_aws_k8s_unmanaged(self):
         return self.build_route("settings/cloudaccounts/aws/computeservices/k8s_unmanaged")
 
+    # new api
+    def add_k8s_compute_service_under_cloud_account(self):
+        return self.build_route("settings/cloudaccounts/computeservices/k8s")
+
     def aws_template(self):
         return self.build_route("settings/cloudaccounts/aws/template")
 
@@ -55,11 +61,9 @@ class ApiSettings(ApiBase):
     def repository(self, name: str):
         return self.build_route(f"settings/repositories/{name}")
 
-    def k8s_agent_deployment_yaml(self, cloud_account_name: str, compute_service_name: str, agent_namespace: str,
-                                  sandbox_namespaces: str):
+    def k8s_agent_deployment_yaml(self, cloud_account_name: str, compute_service_name: str, sandbox_namespaces: str):
         return self.build_route("settings/cloudaccounts/computeservices/k8s/agent-deployment-yaml"
                                 "?cloudAccount={cloud_account_name}"
                                 "&computeService={compute_service_name}"
-                                "&agentNamespace={agent_namespace}"
                                 "&sandboxNamespaces={sandbox_namespaces}"
                                 .format(**locals()))
