@@ -185,6 +185,7 @@ class Colony:
         resp = self.session.post(url=method_url, json=request)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
+    # todo old function -> tomer delete this in phase 2
     def add_azure_aks(self, name: str, cloud_account_name: str, kube_config: str):
         """ Register AKS"""
         method_url = self._api_root.settings.add_compute_service_aks()
@@ -197,6 +198,7 @@ class Colony:
         resp = self.session.post(url=method_url, json=request)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
+    # todo old function -> tomer delete this in phase 2
     def add_aws_k8s_unmanaged(self, name: str, cloud_account_name: str, kube_config: str):
         method_url = self._api_root.settings.add_compute_service_aws_k8s_unmanaged()
         request = {
@@ -208,11 +210,22 @@ class Colony:
         resp = self.session.post(url=method_url, json=request)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
-    def get_k8s_agent_deployment_yaml(self, cloud_account_name: str, compute_service_name: str, agent_namespace: str,
+    # new api
+    def add_k8s_compute_service(self, compute_service_name: str, cloud_account_name: str, agent_namespace: str):
+        method_url = self._api_root.settings.add_k8s_compute_service_under_cloud_account()
+        request = {
+            "compute_service_name": compute_service_name,
+            "cloud_account_name": cloud_account_name,
+            "agent_namespace": agent_namespace
+        }
+
+        resp = self.session.post(url=method_url, json=request)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+    def get_k8s_agent_deployment_yaml(self, cloud_account_name: str, compute_service_name: str,
                                       sandbox_namespaces: List[str]):
         method_url = self._api_root.settings.k8s_agent_deployment_yaml(cloud_account_name=cloud_account_name,
                                                                        compute_service_name=compute_service_name,
-                                                                       agent_namespace=agent_namespace,
                                                                        sandbox_namespaces=','.join(sandbox_namespaces))
         resp = self.session.get(url=method_url)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
