@@ -11,7 +11,7 @@ from gateways.common.cs18_api_classes import AccessLink
 from gateways.common.cs18_api_errors import SandboxError, Error
 
 
-class BlueprintValidationSourceResponse:
+class BlueprintSourceResponse:
     def __init__(self, branch: str, commit: str):
         self.commit = commit
         self.branch = branch
@@ -385,7 +385,9 @@ class SandboxResponseBase:
                  errors: List[SandboxError],
                  scheduled_end_time: datetime,
                  end_time: datetime,
-                 debugging_service: str):
+                 debugging_service: str,
+                 source: BlueprintSourceResponse):
+        self.source = source
         self.sandbox_status = sandbox_status
         self.create_time = create_time
         self.start_time = start_time
@@ -441,7 +443,8 @@ class SandboxResponse(SandboxResponseBase):
                  scheduled_end_time: datetime,
                  end_time: datetime,
                  debugging_service: str,
-                 launching_progress: LaunchingProgress):
+                 launching_progress: LaunchingProgress,
+                 source: BlueprintSourceResponse):
         super().__init__(sandbox_status,
                          create_time,
                          start_time,
@@ -455,7 +458,8 @@ class SandboxResponse(SandboxResponseBase):
                          errors,
                          scheduled_end_time,
                          end_time,
-                         debugging_service)
+                         debugging_service,
+                         source)
         self.artifacts = artifacts
         self.inputs = inputs
         self.applications = applications
@@ -481,7 +485,8 @@ class SandboxResponseLean(SandboxResponseBase):
                  errors: List[SandboxError],
                  scheduled_end_time: datetime,
                  end_time: datetime,
-                 debugging_service: str):
+                 debugging_service: str,
+                 source: BlueprintSourceResponse):
         super().__init__(sandbox_status,
                          create_time,
                          start_time,
@@ -495,7 +500,8 @@ class SandboxResponseLean(SandboxResponseBase):
                          errors,
                          scheduled_end_time,
                          end_time,
-                         debugging_service)
+                         debugging_service,
+                         source)
         self.end_time = end_time
         self.applications = applications
         self.name = name
@@ -956,7 +962,7 @@ class BlueprintValidationResponse:
                  name: str,
                  description: str,
                  url: str,
-                 source: BlueprintValidationSourceResponse,
+                 source: BlueprintSourceResponse,
                  artifacts: Dict[str, str],
                  inputs: List[BlueprintInputResponse],
                  errors: List[Error],
